import { trim } from '../../utils/data/trim.js';
export function isEmpty(value) {
    return (value === 0 ||
        value === 0n ||
        value === undefined ||
        value === null ||
        value === '0' ||
        value === '' ||
        (typeof value === 'string' &&
            (trim(value).toLowerCase() === '0x' ||
                trim(value).toLowerCase() === '0x00')));
}
export function isPresent(value) {
    return !isEmpty(value);
}
export function isEIP1559(transaction) {
    return (isPresent(transaction.maxFeePerGas) &&
        isPresent(transaction.maxPriorityFeePerGas));
}
// process as CIP42 if any of these fields are present. realistically gatewayfee is not used but is part of spec
export function isCIP42(transaction) {
    // Enable end-user to force the tx to be considered as a cip42
    if (transaction.type)
        return transaction.type === 'cip42';
    return (isEIP1559(transaction) &&
        (isPresent(transaction.feeCurrency) ||
            isPresent(transaction.gatewayFeeRecipient) ||
            isPresent(transaction.gatewayFee)));
}
export function isCIP64(transaction) {
    // Enable end-user to force the tx to be considered as a cip64
    if (transaction.type)
        return transaction.type === 'cip64';
    return (isEIP1559(transaction) &&
        isPresent(transaction.feeCurrency) &&
        isEmpty(transaction.gatewayFee) &&
        isEmpty(transaction.gatewayFeeRecipient));
}
//# sourceMappingURL=utils.js.map